==> uppy__drop-target-3.0.1.jar: META-INF/resources/webjars/uppy__drop-target/3.0.1/CHANGELOG.md <==
# @uppy/drop-target

## 3.0.1

Released: 2024-07-15
Included in: Uppy v4.0.1

- @uppy/dashboard,@uppy/drag-drop,@uppy/drop-target: `<Dashboard/>`, `<DragDrop/>`, `drop-target` - new anti-flickering solution (Evgenia Karunus / #5326)

## 3.0.0-beta.5

Released: 2024-06-04
Included in: Uppy v4.0.0-beta.10

- @uppy/drop-target: remove `title` property (Mikael Finstad / #5200)

## 3.0.0-beta.4

Released: 2024-04-29
Included in: Uppy v4.0.0-beta.4

- @uppy/drop-target: change drop event type to DragEvent (Alireza Heydari / #5107)

## 3.0.0-beta.1

Released: 2024-03-28
Included in: Uppy v4.0.0-beta.1

- @uppy/audio,@uppy/dashboard,@uppy/drop-target,@uppy/webcam: add missing exports (Antoine du Hamel / #5014)


## 2.1.0

Released: 2024-04-29
Included in: Uppy v3.25.0

- @uppy/drop-target: change drop event type to DragEvent (Alireza Heydari / #5107)

## 2.0.5

Released: 2024-03-27
Included in: Uppy v3.24.0

- @uppy/audio,@uppy/dashboard,@uppy/drop-target,@uppy/webcam: add missing exports (Antoine du Hamel / #5014)

## 2.0.3

Released: 2024-02-19
Included in: Uppy v3.22.0

- @uppy/drop-target: refactor to typescript (artur paikin / #4863)

## 2.0.1

Released: 2022-09-25
Included in: Uppy v3.1.0

- @uppy/audio,@uppy/aws-s3-multipart,@uppy/aws-s3,@uppy/box,@uppy/companion-client,@uppy/companion,@uppy/compressor,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/drop-target,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/form,@uppy/golden-retriever,@uppy/google-drive,@uppy/image-editor,@uppy/informer,@uppy/instagram,@uppy/locales,@uppy/onedrive,@uppy/progress-bar,@uppy/provider-views,@uppy/react,@uppy/redux-dev-tools,@uppy/remote-sources,@uppy/screen-capture,@uppy/status-bar,@uppy/store-default,@uppy/store-redux,@uppy/svelte,@uppy/thumbnail-generator,@uppy/transloadit,@uppy/tus,@uppy/unsplash,@uppy/url,@uppy/utils,@uppy/vue,@uppy/webcam,@uppy/xhr-upload,@uppy/zoom: add missing entries to changelog for individual packages (Antoine du Hamel / #4092)

## 2.0.0

Released: 2022-08-22
Included in: Uppy v3.0.0

- Switch to ESM

## 2.0.0-beta.2

Released: 2022-08-03
Included in: Uppy v3.0.0-beta.4

- @uppy/drop-target: remove `isFileTransfer` from the public API (Antoine du Hamel / #3932)

## 1.1.3

Released: 2022-04-27
Included in: Uppy v2.9.4

- @uppy/drop-target: refactor to ESM (Antoine du Hamel / #3648)

## 1.1.2

Released: 2022-03-16
Included in: Uppy v2.8.0

- @uppy/drop-target: ignore if dropped elements aren't files (Penar Musaraj / #3563)

==> uppy__drop-target-3.1.1.jar: META-INF/resources/webjars/uppy__drop-target/3.1.1/CHANGELOG.md <==
# @uppy/drop-target

## 3.1.0

Released: 2025-01-06
Included in: Uppy v4.11.0

- @uppy/angular,@uppy/audio,@uppy/aws-s3,@uppy/box,@uppy/companion-client,@uppy/compressor,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/drop-target,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/form,@uppy/golden-retriever,@uppy/google-drive-picker,@uppy/google-drive,@uppy/google-photos-picker,@uppy/google-photos,@uppy/image-editor,@uppy/informer,@uppy/instagram,@uppy/locales,@uppy/onedrive,@uppy/progress-bar,@uppy/provider-views,@uppy/react,@uppy/remote-sources,@uppy/screen-capture,@uppy/status-bar,@uppy/thumbnail-generator,@uppy/transloadit,@uppy/tus,@uppy/unsplash,@uppy/url,@uppy/vue,@uppy/webcam,@uppy/webdav,@uppy/xhr-upload,@uppy/zoom: Remove "paths" from all tsconfig's (Merlijn Vos / #5572)

## 3.0.2

Released: 2024-12-05
Included in: Uppy v4.8.0

- @uppy/audio,@uppy/aws-s3,@uppy/box,@uppy/companion-client,@uppy/compressor,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/drop-target,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/form,@uppy/golden-retriever,@uppy/google-drive,@uppy/google-photos,@uppy/image-editor,@uppy/informer,@uppy/instagram,@uppy/locales,@uppy/onedrive,@uppy/progress-bar,@uppy/provider-views,@uppy/react,@uppy/remote-sources,@uppy/screen-capture,@uppy/status-bar,@uppy/store-default,@uppy/thumbnail-generator,@uppy/transloadit,@uppy/tus,@uppy/unsplash,@uppy/url,@uppy/utils,@uppy/vue,@uppy/webcam,@uppy/xhr-upload,@uppy/zoom: cleanup tsconfig (Mikael Finstad / #5520)

## 3.0.1

Released: 2024-07-15
Included in: Uppy v4.0.1

- @uppy/dashboard,@uppy/drag-drop,@uppy/drop-target: `<Dashboard/>`, `<DragDrop/>`, `drop-target` - new anti-flickering solution (Evgenia Karunus / #5326)

## 3.0.0-beta.5

Released: 2024-06-04
Included in: Uppy v4.0.0-beta.10

- @uppy/drop-target: remove `title` property (Mikael Finstad / #5200)

## 3.0.0-beta.4

Released: 2024-04-29
Included in: Uppy v4.0.0-beta.4

- @uppy/drop-target: change drop event type to DragEvent (Alireza Heydari / #5107)

## 3.0.0-beta.1

Released: 2024-03-28
Included in: Uppy v4.0.0-beta.1

- @uppy/audio,@uppy/dashboard,@uppy/drop-target,@uppy/webcam: add missing exports (Antoine du Hamel / #5014)


## 2.1.0

Released: 2024-04-29
Included in: Uppy v3.25.0

- @uppy/drop-target: change drop event type to DragEvent (Alireza Heydari / #5107)

## 2.0.5

Released: 2024-03-27
Included in: Uppy v3.24.0

- @uppy/audio,@uppy/dashboard,@uppy/drop-target,@uppy/webcam: add missing exports (Antoine du Hamel / #5014)

## 2.0.3

Released: 2024-02-19
Included in: Uppy v3.22.0

- @uppy/drop-target: refactor to typescript (artur paikin / #4863)

## 2.0.1

Released: 2022-09-25
Included in: Uppy v3.1.0

- @uppy/audio,@uppy/aws-s3-multipart,@uppy/aws-s3,@uppy/box,@uppy/companion-client,@uppy/companion,@uppy/compressor,@uppy/core,@uppy/dashboard,@uppy/drag-drop,@uppy/drop-target,@uppy/dropbox,@uppy/facebook,@uppy/file-input,@uppy/form,@uppy/golden-retriever,@uppy/google-drive,@uppy/image-editor,@uppy/informer,@uppy/instagram,@uppy/locales,@uppy/onedrive,@uppy/progress-bar,@uppy/provider-views,@uppy/react,@uppy/redux-dev-tools,@uppy/remote-sources,@uppy/screen-capture,@uppy/status-bar,@uppy/store-default,@uppy/store-redux,@uppy/svelte,@uppy/thumbnail-generator,@uppy/transloadit,@uppy/tus,@uppy/unsplash,@uppy/url,@uppy/utils,@uppy/vue,@uppy/webcam,@uppy/xhr-upload,@uppy/zoom: add missing entries to changelog for individual packages (Antoine du Hamel / #4092)

## 2.0.0

Released: 2022-08-22
Included in: Uppy v3.0.0

- Switch to ESM

## 2.0.0-beta.2

Released: 2022-08-03
Included in: Uppy v3.0.0-beta.4

- @uppy/drop-target: remove `isFileTransfer` from the public API (Antoine du Hamel / #3932)

## 1.1.3

Released: 2022-04-27
Included in: Uppy v2.9.4

- @uppy/drop-target: refactor to ESM (Antoine du Hamel / #3648)

## 1.1.2

Released: 2022-03-16
Included in: Uppy v2.8.0

- @uppy/drop-target: ignore if dropped elements aren't files (Penar Musaraj / #3563)
